@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,9 +24,7 @@ ClawsMailImportData::ClawsMailImportData(QObject *parent, const QList<QVariant>
     mPath = MailImporter::FilterClawsMail::defaultSettingsPath();
 }
 
-ClawsMailImportData::~ClawsMailImportData()
-{
-}
+ClawsMailImportData::~ClawsMailImportData() = default;
 
 bool ClawsMailImportData::foundMailer() const
 {
